from cookgame.game import Kitchen
from .game import Kitchen

print('*' * 30)
print('power by coding-ai.cn')
print('*' * 30)